<!DOCTYPE html>
<html lang="en">
  <head>
    <!-- Google Tag-->
    {{googletag-script}}

    <!-- Setup -->
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, height=device-height, initial-scale:1, user-scalable=no" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <meta name="robots" content="index, follow" />
    <title>{{project}} - Documentation</title>

    <!-- Basic Meta Tags -->
    <meta name="description" content="{{description}}" />
    <meta name="keywords" content="{{keywords}}" />
    <meta name="author" content="{{author}}" />

    <!-- Open Graph Meta Tags -->
    <meta property="og:title" content="{{project}} - Documentation" />
    <meta property="og:description" content="{{description}}" />
    <meta property="og:url" content="{{doc-url}}" />
    <meta property="og:type" content="website" />
    <meta property="og:image" content="{{doc-url}}/assets/logo.ico" />

    <!-- Twitter Card Meta Tags -->
    <meta name="twitter:card" content="summary" />
    <meta name="twitter:title" content="{{project}} - Documentation" />
    <meta name="twitter:description" content="{{description}}" />
    <meta name="twitter:image" content="{{doc-url}}/assets/logo.ico" />

    <!-- Canonical URL -->
    <link rel="canonical" href="{{doc-url}}" />

    <!-- Favicons -->
    <link rel="icon" href="{{doc-url}}/assets/logo.ico" type="image/x-icon" />
    <link rel="apple-touch-icon" href="{{doc-url}}/assets/logo.ico" />

    <!-- Sitemaps -->
    <link rel="sitemap" type="application/xml" title="Sitemap" href="{{doc-url}}/assets/sitemap.xml" />

    <!-- SEO Enhancements -->
    <meta name="theme-color" content="{{main-dark}}" />
    <meta name="application-name" content="{{project}} - Documentation" />
    <meta name="msapplication-TileColor" content="{{main-dark}}" />

    <!-- Copyrighted -->
    {{copyrighted-meta}}

    <!-- Structured Data (JSON-LD) -->
    <script type="application/ld+json">
      {
        "@context": "https://schema.org",
        "@type": "DocumentationPage",
        "name": "{{project}} - Documentation",
        "headline": "{{project}} - Documentation",
        "description": "{{description}}",
        "url": "{{doc-url}}",
        "author": {
          "@type": "Person",
          "name": "{{author}}",
          "sameAs": "{{linkedin}}",
          "jobTitle": "{{position}}",
          "image": "{{doc-url}}/assets/author.png"
        },
        "creator": {
          "@type": "Person",
          "name": "{{author}}",
          "sameAs": "{{linkedin}}",
          "jobTitle": "{{position}}",
          "image": "{{doc-url}}/assets/author.png"
        },
        "publisher": {
          "@type": "Person",
          "name": "{{author}}",
          "sameAs": "{{linkedin}}",
          "jobTitle": "{{position}}",
          "image": "{{doc-url}}/assets/author.png"
        }
      }
    </script>
    <script type="application/ld+json">
      {
        "@context": "https://schema.org",
        "@type": "Person",
        "name": "{{author}}",
        "sameAs": "{{linkedin}}",
        "jobTitle": "{{position}}",
        "image": "{{doc-url}}/assets/author.png"
      }
    </script>

    <link rel="stylesheet" href="{{doc-url}}/assets/bootstrap.icons.css" />
    <link rel="stylesheet" href="{{doc-url}}/assets/docipy.css" />
    <script src="{{doc-url}}/assets/highlight.js"></script>
    <script>
      hljs.highlightAll();
    </script>
  </head>
  <body>
    <span class="bi bi-list"></span>
    <div id="version">
      <span desc="current-version-number" class="bi bi-chevron-down">v{{version}}</span>
      <ul>
        <!-- VERSIONS-START -->
        {{versions}}
        <!-- VERSIONS-END -->
      </ul>
    </div>
    <header>
      <a href="#docipy">
        <span>{{project}}</span>
        <hint>Home</hint>
      </a>
      <div>
        <input type="text" placeholder="Search . . ." />
        <i class="bi bi-search"></i>
      </div>
      <nav>{{menus}}</nav>
    </header>
    <div class="docipy-docipyblock">
      <section id="docipy" {{background-image}}>
        <div>
          <img src="{{doc-url}}/assets/logo.ico" alt=" " />
          <h1>{{project}}</h1>
          <h2>{{slogan}}</h2>
          <div class="buttons">
            <a href="{{button1-link}}">{{button1-name}}</a>
            <a href="{{button2-link}}">{{button2-name}}</a>
          </div>
          <div class="author">
            <div class="person">
              <img src="{{doc-url}}/assets/author.png" alt=" " />
              <div>
                <p>{{author}}</p>
                <span>{{position}}</span>
              </div>
            </div>
            <div class="links">
              <a href="{{linkedin}}" target="_blank" style="background: #0a66c2">Follow on LinkedIn</a>
              <a href="mailto:{{email}}" style="background: #e35344" target="_blank">Send Email</a>
              <a href="{{x}}" target="_blank" style="background: #373737">Follow on X</a>
            </div>
          </div>
        </div>
      </section>
    </div>
    {{blocks}}
    <footer>
      <div>
        <p>{{project}} - v{{version}}</p>
        <a href="#docipy">Home</a>
        <a href="{{button1-link}}">{{button1-name}}</a>
        <a href="{{button2-link}}">{{button2-name}}</a>
      </div>
      <div>
        <p>{{author}}</p>
        <a href="{{linkedin}}" target="_blank">Follow on LinkedIn</a>
        <a href="mailto:{{email}}" target="_blank">Send Email</a>
        <a href="{{x}}" target="_blank">Follow on X</a>
      </div>
      <div>
        <p>Powered by DociPy</p>
        <a href="{{docipy-page}}" target="_blank" class="bi bi-arrow-up-right-circle">{{docipy-hint}}</a>
        {{copyrighted-badge}}
      </div>
    </footer>
  </body>
</html>
<script src="{{doc-url}}/assets/docipy.js"></script>
